pilot.impl

Package pilot :: Package impl |

# Package impl

source code

BigJob-based Implementation of Pilot-API

This package contains the implementations of the Pilot API objects: PilotComputeService, PilotCompute, PilotDataService, PilotData, ComputeDataService.

Submodules
pilot.impl.pilot_manager: ComputeDataService Module: A central implementation of the ComputeDataService pilot.impl.pilot_manager_decentral: ComputeDataServiceDecentral Module: A decentral implementation of a ComputeDataService (see ComputeDataServiceDecentral). pilot.impl.pilotcompute_manager: PilotCompute Module: Implementation of PilotComputeService, PilotCompute, ComputeUnit. pilot.impl.pilotdata_manager: PilotData Module: Implementation of PilotData, PilotDataService and DataUnit

Variables
| __package__ = `None` hash(x)